import os
import setuptools

from setuptools import setup, find_packages

with open(os.path.join(os.path.abspath(os.path.dirname(__file__)), 'README.rst'), encoding='utf-8') as f:
    lines = f.readlines()
    description_content = "".join(lines)

setup(
    name="systemathics.apis",
    version="0.11.2-rc0",
    author="Systemathics",
    author_email="contact@systemathics.com",
    description="Python grpc stub for Systemathics APIs.",
    url="https://github.com/systemathics/sdk-python",
    packages=find_packages(),
    namespace_packages=['systemathics'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Intended Audience :: Information Technology",
        "Intended Audience :: Science/Research"
    ],
    license='MIT',
    python_requires='>=3.6',
    install_requires=['googleapis-common-protos', 'protobuf', 'grpcio'],
    long_description= description_content,
    long_description_content_type="text/x-rst; charset=UTF-8"
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_priips.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>systemathics/apis/services/tick_analytics/v1/tick_priips.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xe8\x02\n\x11TickPriipsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12.\n\norder_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0e\x65xecution_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x65xecution_price\x18\x04 \x01(\x01\x12H\n\x05\x66ield\x18\x05 \x01(\x0e\x32\x39.systemathics.apis.services.tick_analytics.v1.PriipsPrice\x12*\n\x07latency\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x07 \x03(\t\x12\x0e\n\x06reject\x18\x08 \x03(\t\"\xa5\x04\n\x12TickPriipsResponse\x12\x30\n\x0c\x61rrival_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rarrival_price\x18\x02 \x01(\x01\x12\x14\n\x0c\x61rrival_cost\x18\x03 \x01(\x01\x12-\n\topen_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nclose_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\norder_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0e\x65xecution_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12*\n\x07latency\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x17\n\x0f\x65xecution_price\x18\n \x01(\x01\x12\r\n\x05\x63ount\x18\x0b \x01(\x03\x12\x12\n\nopen_price\x18\x0c \x01(\x01\x12\x12\n\nhigh_price\x18\r \x01(\x01\x12\x11\n\tlow_price\x18\x0e \x01(\x01\x12\x13\n\x0b\x63lose_price\x18\x0f \x01(\x01\x12\x0c\n\x04vwap\x18\x10 \x01(\x01\x12\x0e\n\x06volume\x18\x11 \x01(\x03*o\n\x0bPriipsPrice\x12\x1c\n\x18PRIIPS_PRICE_UNSPECIFIED\x10\x00\x12\x16\n\x12PRIIPS_PRICE_TRADE\x10\x01\x12\x14\n\x10PRIIPS_PRICE_BID\x10\x02\x12\x14\n\x10PRIIPS_PRICE_ASK\x10\x03\x32\xa7\x01\n\x11TickPriipsService\x12\x91\x01\n\nTickPriips\x12?.systemathics.apis.services.tick_analytics.v1.TickPriipsRequest\x1a@.systemathics.apis.services.tick_analytics.v1.TickPriipsResponse0\x01\x62\x06proto3')

_PRIIPSPRICE = DESCRIPTOR.enum_types_by_name['PriipsPrice']
PriipsPrice = enum_type_wrapper.EnumTypeWrapper(_PRIIPSPRICE)
PRIIPS_PRICE_UNSPECIFIED = 0
PRIIPS_PRICE_TRADE = 1
PRIIPS_PRICE_BID = 2
PRIIPS_PRICE_ASK = 3


_TICKPRIIPSREQUEST = DESCRIPTOR.message_types_by_name['TickPriipsRequest']
_TICKPRIIPSRESPONSE = DESCRIPTOR.message_types_by_name['TickPriipsResponse']
TickPriipsRequest = _reflection.GeneratedProtocolMessageType('TickPriipsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKPRIIPSREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_priips_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickPriipsRequest)
  })
_sym_db.RegisterMessage(TickPriipsRequest)

TickPriipsResponse = _reflection.GeneratedProtocolMessageType('TickPriipsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKPRIIPSRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_priips_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickPriipsResponse)
  })
_sym_db.RegisterMessage(TickPriipsResponse)

_TICKPRIIPSSERVICE = DESCRIPTOR.services_by_name['TickPriipsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRIIPSPRICE._serialized_start=1143
  _PRIIPSPRICE._serialized_end=1254
  _TICKPRIIPSREQUEST._serialized_start=229
  _TICKPRIIPSREQUEST._serialized_end=589
  _TICKPRIIPSRESPONSE._serialized_start=592
  _TICKPRIIPSRESPONSE._serialized_end=1141
  _TICKPRIIPSSERVICE._serialized_start=1257
  _TICKPRIIPSSERVICE._serialized_end=1424
# @@protoc_insertion_point(module_scope)
